@@ -17,8 +17,7 @@ namespace builtins
   {
     template <class Tuple, size_t N>
     struct tuple_sum {
-      auto operator()(Tuple const &t) -> decltype(std::get<N>(t) +
-                                                  tuple_sum<Tuple, N - 1>()(t));
+      auto operator()(Tuple const &t) -> decltype(std::get<N>(t) + tuple_sum<Tuple, N - 1>()(t));
     };
 
     template <class Tuple>
@@ -28,11 +27,9 @@ namespace builtins
   } // namespace details
 
   template <class Iterable, class T>
-  auto sum(Iterable s, T start)
-      -> decltype(std::accumulate(
-          s.begin(), s.end(),
-          static_cast<typename assignable<decltype(start + *s.begin())>::type>(
-              start)));
+  auto sum(Iterable s, T start) -> decltype(std::accumulate(
+      s.begin(), s.end(),
+      static_cast<typename assignable<decltype(start + *s.begin())>::type>(start)));
 
   template <class Iterable>
   auto sum(Iterable s) -> decltype(sum(s, 0L))
@@ -42,8 +39,7 @@ namespace builtins
 
   template <class... Types>
   auto sum(std::tuple<Types...> const &t)
-      -> decltype(details::tuple_sum<std::tuple<Types...>,
-                                     sizeof...(Types) - 1>()(t))
+      -> decltype(details::tuple_sum<std::tuple<Types...>, sizeof...(Types) - 1>()(t))
   {
     return details::tuple_sum<std::tuple<Types...>, sizeof...(Types) - 1>()(t);
   }
