@@ -1,8 +1,8 @@
 #ifndef PYTHONIC_INCLUDE_NUMPY_COSH_HPP
 #define PYTHONIC_INCLUDE_NUMPY_COSH_HPP
 
-#include "pythonic/include/utils/functor.hpp"
 #include "pythonic/include/types/ndarray.hpp"
+#include "pythonic/include/utils/functor.hpp"
 #include "pythonic/include/utils/numpy_traits.hpp"
 
 #include <xsimd/xsimd.hpp>
@@ -14,7 +14,7 @@ namespace numpy
 #define NUMPY_NARY_FUNC_NAME cosh
 #define NUMPY_NARY_FUNC_SYM xsimd::cosh
 #include "pythonic/include/types/numpy_nary_expr.hpp"
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
