@@ -9,10 +9,9 @@ PYTHONIC_NS_BEGIN
 namespace numpy
 {
   template <class E>
-  auto
-  fliplr(E &&expr) -> decltype(std::forward<E>(expr)(
-                       types::cstride_slice<1>{builtins::None, builtins::None},
-                       types::slice{builtins::None, builtins::None, -1}));
+  auto fliplr(E &&expr)
+      -> decltype(std::forward<E>(expr)(types::cstride_slice<1>{builtins::None, builtins::None},
+                                        types::slice{builtins::None, builtins::None, -1}));
 
   DEFINE_FUNCTOR(pythonic::numpy, fliplr);
 } // namespace numpy
