@@ -12,12 +12,10 @@ namespace numpy
   namespace random
   {
     template <class pS>
-    types::ndarray<long, pS> negative_binomial(long n, double p,
-                                               pS const &shape);
+    types::ndarray<long, pS> negative_binomial(long n, double p, pS const &shape);
 
     auto negative_binomial(long n, double p, long size)
-        -> decltype(negative_binomial(n, p,
-                                      types::array_tuple<long, 1>{{size}}));
+        -> decltype(negative_binomial(n, p, types::array_tuple<long, 1>{{size}}));
 
     long negative_binomial(long n, double p, types::none_type size = {});
 
