@@ -3,9 +3,9 @@
 
 #include "pythonic/include/numpy/copy.hpp"
 
+#include "pythonic/types/ndarray.hpp"
 #include "pythonic/utils/functor.hpp"
 #include "pythonic/utils/numpy_conversion.hpp"
-#include "pythonic/types/ndarray.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -13,9 +13,8 @@ namespace numpy
 {
   // list case
   template <class E>
-  typename std::enable_if<
-      !types::is_array<E>::value && !types::is_dtype<E>::value,
-      types::ndarray<typename E::dtype, types::array<long, E::value>>>::type
+  std::enable_if_t<!types::is_array<E>::value && !types::is_dtype<E>::value,
+                   types::ndarray<typename E::dtype, types::array_tuple<long, E::value>>>
   copy(E const &v)
   {
     return {v};
@@ -23,17 +22,14 @@ namespace numpy
 
   // scalar / complex case
   template <class E>
-  auto copy(E const &v) ->
-      typename std::enable_if<types::is_dtype<E>::value, E>::type
+  auto copy(E const &v) -> std::enable_if_t<types::is_dtype<E>::value, E>
   {
     return v;
   }
 
   // No copy is required for numpy_expr
   template <class E>
-  auto copy(E &&v) ->
-      typename std::enable_if<types::is_array<E>::value,
-                              decltype(std::forward<E>(v))>::type
+  auto copy(E &&v) -> std::enable_if_t<types::is_array<E>::value, decltype(std::forward<E>(v))>
   {
     return std::forward<E>(v);
   }
@@ -47,12 +43,11 @@ namespace numpy
 
   // transposed ndarray case
   template <class T, class pS>
-  types::numpy_texpr<types::ndarray<T, pS>>
-  copy(types::numpy_texpr<types::ndarray<T, pS>> const &a)
+  types::numpy_texpr<types::ndarray<T, pS>> copy(types::numpy_texpr<types::ndarray<T, pS>> const &a)
   {
     return a.arg.copy();
   }
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
