@@ -12,8 +12,8 @@ namespace operator_
 {
 
   template <class A, class B>
-  auto is_(A &&a, B &&b) -> decltype(builtins::id(std::forward<A>(a)) ==
-                                     builtins::id(std::forward<B>(b)))
+  auto is_(A &&a, B &&b)
+      -> decltype(builtins::id(std::forward<A>(a)) == builtins::id(std::forward<B>(b)))
   {
     return builtins::id(std::forward<A>(a)) == builtins::id(std::forward<B>(b));
   }
